@@ -9,13 +9,12 @@ from onnx.reference.ops._op_common_window import _CommonWindow
 
 
 class BlackmanWindow(_CommonWindow):
-    """
-    Returns
-    :math:`\\omega_n = 0.42 - 0.5 \\cos \\left( \\frac{2\\pi n}{N-1} \\right) +
-    0.08 \\cos \\left( \\frac{4\\pi n}{N-1} \\right)`
+    r"""Blankman windowing function.
+
+    Returns :math:`\\omega_n = 0.42 - 0.5 \\cos \\left( \\frac{2\\pi n}{N-1} \\right) + 0.08 \\cos \\left( \\frac{4\\pi n}{N-1} \\right)`
     where *N* is the window length.
-    See `blackman_window
-    <https://pytorch.org/docs/stable/generated/torch.blackman_window.html>`_
+
+    See `blackman_window <https://pytorch.org/docs/stable/generated/torch.blackman_window.html>`_
     """
 
     def _run(self, size, output_datatype=None, periodic=None):  # type: ignore
